/**
 * Copyright (c) 2014-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.registry.client.mock;

import java.net.UnknownHostException;
import java.util.Map;

import org.ow2.petals.registry.client.api.PetalsRegistryClient;
import org.ow2.petals.registry.client.api.PetalsRegistryClientFactory;
import org.ow2.petals.registry.client.api.exception.ConnectionErrorException;
import org.ow2.petals.topology.generated.Topology;

/**
 * The factory to create mock of Petals Registry Client API
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class PetalsRegistryClientFactoryMock extends PetalsRegistryClientFactory {

    /**
     * The map in which topologies will be registered
     */
    private Map<String, Topology> topologyMap;

    public void setTopologyMap(final Map<String, Topology> topologyMap) {
        this.topologyMap = topologyMap;
    }

    @Override
    public PetalsRegistryClient createClient(final String host, final Integer port, final String group,
            final String password) throws ConnectionErrorException {
        try {
            return new PetalsRegistryClientMock(host, port, group, password, this.topologyMap);
        } catch (final UnknownHostException e) {
            throw new ConnectionErrorException(e);
        }
    }

}
