/**
 * Copyright (c) 2014-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.registry.client.mock;

import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.Collections;
import java.util.Map;

import org.ow2.petals.registry.client.api.PetalsRegistryClient;
import org.ow2.petals.registry.client.api.exception.ConnectionErrorException;
import org.ow2.petals.registry.client.api.exception.UnexistingTopologyException;
import org.ow2.petals.topology.generated.Topology;

/**
 * A mocked client of the Petals Registry Client API
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class PetalsRegistryClientMock implements PetalsRegistryClient {

    /**
     * The map in which topologies will be registered
     */
    private Map<String, Topology> topologyMap;

    private final InetAddress host;

    private final Integer port;

    private final String group;

    public PetalsRegistryClientMock(final String host, final Integer port, final String group, final String password,
            final Map<String, Topology> topologyMap) throws UnknownHostException {
        this.topologyMap = topologyMap;
        this.host = InetAddress.getByName(host);
        this.port = port;
        this.group = group;
    }

    @Override
    public InetAddress getHost() {
        return this.host;
    }

    @Override
    public int getPort() {
        return this.port.intValue();
    }

    @Override
    public String getGroup() {
        return this.group;
    }

    @Override
    public void disconnect() throws ConnectionErrorException {
        // TODO Auto-generated method stub
    }

    @Override
    public Map<String, Topology> getTopologies() {
        return Collections.unmodifiableMap(this.topologyMap);
    }

    @Override
    public Topology getTopology(final String topologyId) {
        return this.topologyMap.get(topologyId);
    }

    @Override
    public void clean(final String topologyId) throws UnexistingTopologyException {
        if (this.topologyMap.containsKey(topologyId)) {
            this.topologyMap.remove(topologyId);
        } else {
            throw new UnexistingTopologyException(topologyId);
        }
    }
}
